Package: simPop
Type: Package
Title: Simulation of Complex Synthetic Data Information
Version: 2.1.3
Date: 2024-01-05
Authors@R: c(
  person("Matthias", "Templ", email = "matthias.templ@gmail.com", role = c("aut","cre")),
  person("Alexander", "Kowarik", email = "alexander.kowarik@statistik.gv.at", role = c("aut"), comment=c(ORCID="0000-0001-8598-4130")),
  person("Bernhard", "Meindl", email = "bernhard.meindl@statistik.gv.at", role = c("aut")),
  person("Andreas", "Alfons", role = c("aut")),
  person("Mathieu", "Ribatet", role = c("ctb")),
  person("Johannes", "Gussenbauer", email = "johannes.gussenbauer@statistik.gv.at", role = c("ctb")),
  person("Siro", "Fritzmann", email = "siro.fritzmann@bluewin.ch",  role = c("ctb")))
URL: https://github.com/statistikat/simPop
Depends: R(>= 3.0.0), lattice, vcd
Imports: data.table, MASS, Rcpp (>= 0.11.0), RcppArmadillo, e1071,
        parallel, nnet, doParallel, foreach, colorspace, VIM, methods,
        EnvStats, fitdistrplus, ranger, wrswoR, matrixStats, xgboost,
        partykit
Suggests: haven, microbenchmark, stringr, tinytest, sampling, covr
LinkingTo: Rcpp,RcppArmadillo
Description: Tools and methods to simulate populations for surveys based
    on auxiliary data. The tools include model-based methods, calibration and
    combinatorial optimization algorithms, see Templ, Kowarik and Meindl (2017) <doi:10.18637/jss.v079.i10>) and
    Templ (2017) <doi:10.1007/978-3-319-50272-4>. The package was developed with support of
    the International Household Survey Network, DFID Trust Fund TF011722 and funds
    from the World bank.
License: GPL (>= 2)
LazyLoad: yes
ByteCompile: TRUE
Collate: '0classes.R' 'addKnownMargins.R' 'addWeights.r' 'calibPop.R'
        'calibSample.R' 'calibVars.R' 'contingencyWt.R' 'correctHeap.R'
        'crossValidation.R' 'fitGPD.R' 'getBreaks.R' 'getCat.R' 'ipu.r'
        'meanWt.R' 'printFunctions.R' 'quantileWt.R' 'sampHH.R'
        'RcppExports.R' 'silcTools.R' 'silcTools2.R' 'simAnnealingDT.R'
        'simCategorical.R' 'simComponents.R' 'simContinuous.R'
        'simEUSILC.R' 'simGPD.R' 'simInitSpatial.R' 'simple_dis.R'
        'simPop-package.R' 'simRelation.R' 'simStructure.R'
        'spBwplot.R' 'spBwplotStats.R' 'spCdf.R' 'spCdfplot.R'
        'spMosaic.R' 'spPredict.R' 'spSample.R' 'spTable.R'
        'specifyInput.R' 'sprague.R' 'tableWt.R' 'utility.R' 'utils.R'
        'whipple.R' 'dataSets.R' 'zzz.R'
RoxygenNote: 7.2.3
Encoding: UTF-8
NeedsCompilation: yes
Packaged: 2024-01-05 10:41:47 UTC; gussen
Author: Matthias Templ [aut, cre],
  Alexander Kowarik [aut] (<https://orcid.org/0000-0001-8598-4130>),
  Bernhard Meindl [aut],
  Andreas Alfons [aut],
  Mathieu Ribatet [ctb],
  Johannes Gussenbauer [ctb],
  Siro Fritzmann [ctb]
Maintainer: Matthias Templ <matthias.templ@gmail.com>
Repository: CRAN
Date/Publication: 2024-01-08 10:40:02 UTC
Built: R 4.6.0; aarch64-apple-darwin23; 2026-04-25 14:05:58 UTC; unix
Archs: simPop.so.dSYM
