# Generated by roxygen2: do not edit by hand

S3method(calibVars,data.frame)
S3method(calibVars,default)
S3method(calibVars,matrix)
S3method(contingencyWt,data.frame)
S3method(contingencyWt,default)
S3method(contingencyWt,matrix)
S3method(corWt,data.frame)
S3method(corWt,dataObj)
S3method(corWt,default)
S3method(corWt,matrix)
S3method(covWt,data.frame)
S3method(covWt,dataObj)
S3method(covWt,default)
S3method(covWt,matrix)
S3method(meanWt,dataObj)
S3method(meanWt,default)
S3method(prepBwplotStats,data.frame)
S3method(prepBwplotStats,default)
S3method(prepCdf,data.frame)
S3method(prepCdf,default)
S3method(quantileWt,dataObj)
S3method(quantileWt,default)
S3method(varWt,dataObj)
S3method(varWt,default)
export("addWeights<-")
export("pop<-")
export("popObj<-")
export("samp<-")
export("sampleObj<-")
export(addKnownMargins)
export(calibPop)
export(calibSample)
export(calibVars)
export(checkCol)
export(chooseSILCvars)
export(conditional.dis)
export(contingencyWt)
export(corWt)
export(correctHeaps)
export(correctSingleHeap)
export(covWt)
export(crossValidation)
export(factorNA)
export(getAge)
export(getBreaks)
export(getBwplotStats)
export(getCat)
export(getCdf)
export(getCitizenship)
export(getEcoStat)
export(getGender)
export(getHsize)
export(ipu)
export(loadSILC)
export(manageSimPopObj)
export(meanWt)
export(mergeSILC)
export(modifySILC)
export(panelSpBwplot)
export(panelSpCdfplot)
export(pop)
export(popData)
export(popObj)
export(prepBwplotStats)
export(prepCdf)
export(prepanelSpCdfplot)
export(quantileWt)
export(restructureHHid)
export(samp)
export(sampHH)
export(sampleData)
export(sampleObj)
export(simCategorical)
export(simComponents)
export(simContinuous)
export(simEUSILC)
export(simInitSpatial)
export(simRelation)
export(simStructure)
export(spBwplot)
export(spBwplotStats)
export(spCdf)
export(spCdfplot)
export(spMosaic)
export(spTable)
export(specifyInput)
export(sprague)
export(tableObj)
export(tableWt)
export(univariate.dis)
export(utility)
export(utilityIndicator)
export(utilityModal)
export(varWt)
export(whipple)
exportMethods("addWeights<-")
exportMethods("pop<-")
exportMethods("popObj<-")
exportMethods("samp<-")
exportMethods("sampleObj<-")
exportMethods(calibSample)
exportMethods(pop)
exportMethods(popData)
exportMethods(popObj)
exportMethods(sampleData)
exportMethods(sampleObj)
exportMethods(tableObj)
import(Rcpp)
import(data.table)
import(doParallel)
import(e1071)
import(fitdistrplus)
import(foreach)
import(methods)
import(nnet)
import(parallel)
import(vcd)
import(xgboost)
importFrom(EnvStats,rlnormTrunc)
importFrom(EnvStats,rnormTrunc)
importFrom(MASS,ginv)
importFrom(RcppArmadillo,armadillo_version)
importFrom(VIM,hotdeck)
importFrom(colorspace,heat_hcl)
importFrom(fitdistrplus,fitdist)
importFrom(graphics,par)
importFrom(lattice,bwplot)
importFrom(lattice,packet.number)
importFrom(lattice,panel.bwplot)
importFrom(lattice,panel.points)
importFrom(lattice,panel.refline)
importFrom(lattice,panel.xyplot)
importFrom(matrixStats,colMeans2)
importFrom(matrixStats,colSds)
importFrom(partykit,cforest)
importFrom(partykit,ctree)
importFrom(ranger,ranger)
importFrom(stats,as.formula)
importFrom(stats,chisq.test)
importFrom(stats,coef)
importFrom(stats,cor)
importFrom(stats,cov)
importFrom(stats,dlogis)
importFrom(stats,formula)
importFrom(stats,glm)
importFrom(stats,lm)
importFrom(stats,mad)
importFrom(stats,median)
importFrom(stats,model.frame)
importFrom(stats,model.matrix)
importFrom(stats,na.omit)
importFrom(stats,na.pass)
importFrom(stats,optim)
importFrom(stats,plogis)
importFrom(stats,poisson)
importFrom(stats,ppoints)
importFrom(stats,predict)
importFrom(stats,quantile)
importFrom(stats,rexp)
importFrom(stats,rnorm)
importFrom(stats,runif)
importFrom(stats,sd)
importFrom(stats,terms)
importFrom(stats,uniroot)
importFrom(stats,var)
importFrom(stats,weighted.mean)
importFrom(stats,xtabs)
importFrom(utils,head)
importFrom(utils,read.csv2)
importFrom(utils,tail)
importFrom(wrswoR,sample_int_crank)
useDynLib(simPop)
