[![R-CMD-check](https://github.com/statistikat/simPop/actions/workflows/R-CMD-check.yaml/badge.svg)](https://github.com/statistikat/simPop/actions/workflows/R-CMD-check.yaml)
[![Codecov test coverage](https://codecov.io/gh/statistikat/simPop/branch/master/graph/badge.svg)](https://app.codecov.io/gh/statistikat/simPop?branch=master)
[![CRAN](http://www.r-pkg.org/badges/version/simPop)](https://CRAN.R-project.org/package=simPop)
[![Downloads](http://cranlogs.r-pkg.org/badges/simPop)](https://CRAN.R-project.org/package=simPop)
[![Mentioned in Awesome Official Statistics ](https://awesome.re/mentioned-badge.svg)](https://github.com/SNStatComp/awesome-official-statistics-software)

## simPop

This is the development place for R-package simPop
